@@ -6,62 +6,70 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -------------------------------------------------------------------------
  */
 
 
 #include "geojson_printer.h"
+#include "pvt_solution.h"
 #include <boost/date_time/posix_time/posix_time.hpp>
+#include <glog/logging.h>
+#include <ctime>      // for tm
+#include <exception>  // for exception
+#include <iomanip>    // for operator<<
+#include <iostream>   // for cout, cerr
+#include <sstream>    // for stringstream
+
+#if HAS_STD_FILESYSTEM
+#include <system_error>
+namespace errorlib = std;
+#if HAS_STD_FILESYSTEM_EXPERIMENTAL
+#include <experimental/filesystem>
+namespace fs = std::experimental::filesystem;
+#else
+#include <filesystem>
+namespace fs = std::filesystem;
+#endif
+#else
 #include <boost/filesystem/operations.hpp>   // for create_directories, exists
 #include <boost/filesystem/path.hpp>         // for path, operator<<
 #include <boost/filesystem/path_traits.hpp>  // for filesystem
-#include <glog/logging.h>
-#include <iomanip>
-#include <sstream>
-
+#include <boost/system/error_code.hpp>       // for error_code
+namespace fs = boost::filesystem;
+namespace errorlib = boost::system;
+#endif
 
 GeoJSON_Printer::GeoJSON_Printer(const std::string& base_path)
 {
     first_pos = true;
     geojson_base_path = base_path;
-    boost::filesystem::path full_path(boost::filesystem::current_path());
-    const boost::filesystem::path p(geojson_base_path);
-    if (!boost::filesystem::exists(p))
+    fs::path full_path(fs::current_path());
+    const fs::path p(geojson_base_path);
+    if (!fs::exists(p))
         {
             std::string new_folder;
-            for (auto& folder : boost::filesystem::path(geojson_base_path))
+            for (auto& folder : fs::path(geojson_base_path))
                 {
                     new_folder += folder.string();
-                    boost::system::error_code ec;
-                    if (!boost::filesystem::exists(new_folder))
+                    errorlib::error_code ec;
+                    if (!fs::exists(new_folder))
                         {
-                            if (!boost::filesystem::create_directory(new_folder, ec))
+                            if (!fs::create_directory(new_folder, ec))
                                 {
                                     std::cout << "Could not create the " << new_folder << " folder." << std::endl;
                                     geojson_base_path = full_path.string();
                                 }
                         }
-                    new_folder += boost::filesystem::path::preferred_separator;
+                    new_folder += fs::path::preferred_separator;
                 }
         }
     else
@@ -73,13 +81,20 @@ GeoJSON_Printer::GeoJSON_Printer(const std::string& base_path)
             std::cout << "GeoJSON files will be stored at " << geojson_base_path << std::endl;
         }
 
-    geojson_base_path = geojson_base_path + boost::filesystem::path::preferred_separator;
+    geojson_base_path = geojson_base_path + fs::path::preferred_separator;
 }
 
 
 GeoJSON_Printer::~GeoJSON_Printer()
 {
-    GeoJSON_Printer::close_file();
+    try
+        {
+            GeoJSON_Printer::close_file();
+        }
+    catch (const std::exception& e)
+        {
+            std::cerr << e.what() << '\n';
+        }
 }
 
 
@@ -213,7 +228,11 @@ bool GeoJSON_Printer::close_file()
             // if nothing is written, erase the file
             if (first_pos == true)
                 {
-                    if (remove(filename_.c_str()) != 0) LOG(INFO) << "Error deleting temporary file";
+                    errorlib::error_code ec;
+                    if (!fs::remove(fs::path(filename_), ec))
+                        {
+                            LOG(INFO) << "Error deleting temporary file";
+                        }
                 }
             return true;
         }
