@@ -11,46 +11,38 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -------------------------------------------------------------------------
  */
 
-#ifndef GNSS_SDR_PCPS_CCCWSR_ACQUISITION_CC_H_
-#define GNSS_SDR_PCPS_CCCWSR_ACQUISITION_CC_H_
+#ifndef GNSS_SDR_PCPS_CCCWSR_ACQUISITION_CC_H
+#define GNSS_SDR_PCPS_CCCWSR_ACQUISITION_CC_H
 
+#include "channel_fsm.h"
 #include "gnss_synchro.h"
 #include <gnuradio/block.h>
 #include <gnuradio/fft/fft.h>
 #include <gnuradio/gr_complex.h>
 #include <fstream>
+#include <memory>
 #include <string>
+#include <utility>
+#include <vector>
 
 
 class pcps_cccwsr_acquisition_cc;
 
-typedef boost::shared_ptr<pcps_cccwsr_acquisition_cc> pcps_cccwsr_acquisition_cc_sptr;
+using pcps_cccwsr_acquisition_cc_sptr = boost::shared_ptr<pcps_cccwsr_acquisition_cc>;
 
-pcps_cccwsr_acquisition_cc_sptr
-pcps_cccwsr_make_acquisition_cc(
+pcps_cccwsr_acquisition_cc_sptr pcps_cccwsr_make_acquisition_cc(
     uint32_t sampled_ms,
     uint32_t max_dwells,
     uint32_t doppler_max,
@@ -58,7 +50,7 @@ pcps_cccwsr_make_acquisition_cc(
     int32_t samples_per_ms,
     int32_t samples_per_code,
     bool dump,
-    std::string dump_filename);
+    const std::string& dump_filename);
 
 /*!
  * \brief This class implements a Parallel Code Phase Search Acquisition with
@@ -66,58 +58,6 @@ pcps_cccwsr_make_acquisition_cc(
  */
 class pcps_cccwsr_acquisition_cc : public gr::block
 {
-private:
-    friend pcps_cccwsr_acquisition_cc_sptr
-    pcps_cccwsr_make_acquisition_cc(uint32_t sampled_ms, uint32_t max_dwells,
-        uint32_t doppler_max, int64_t fs_in,
-        int32_t samples_per_ms, int32_t samples_per_code,
-        bool dump, std::string dump_filename);
-
-    pcps_cccwsr_acquisition_cc(uint32_t sampled_ms, uint32_t max_dwells,
-        uint32_t doppler_max, int64_t fs_in,
-        int32_t samples_per_ms, int32_t samples_per_code,
-        bool dump, std::string dump_filename);
-
-    void calculate_magnitudes(gr_complex* fft_begin, int32_t doppler_shift,
-        int32_t doppler_offset);
-
-    int64_t d_fs_in;
-    int32_t d_samples_per_ms;
-    int32_t d_samples_per_code;
-    uint32_t d_doppler_resolution;
-    float d_threshold;
-    std::string d_satellite_str;
-    uint32_t d_doppler_max;
-    uint32_t d_doppler_step;
-    uint32_t d_sampled_ms;
-    uint32_t d_max_dwells;
-    uint32_t d_well_count;
-    uint32_t d_fft_size;
-    uint64_t d_sample_counter;
-    gr_complex** d_grid_doppler_wipeoffs;
-    uint32_t d_num_doppler_bins;
-    gr_complex* d_fft_code_data;
-    gr_complex* d_fft_code_pilot;
-    gr::fft::fft_complex* d_fft_if;
-    gr::fft::fft_complex* d_ifft;
-    Gnss_Synchro* d_gnss_synchro;
-    uint32_t d_code_phase;
-    float d_doppler_freq;
-    float d_mag;
-    float* d_magnitude;
-    gr_complex* d_data_correlation;
-    gr_complex* d_pilot_correlation;
-    gr_complex* d_correlation_plus;
-    gr_complex* d_correlation_minus;
-    float d_input_power;
-    float d_test_statistics;
-    std::ofstream d_dump_file;
-    bool d_active;
-    int32_t d_state;
-    bool d_dump;
-    uint32_t d_channel;
-    std::string d_dump_filename;
-
 public:
     /*!
      * \brief Default destructor.
@@ -135,85 +75,146 @@ public:
     }
 
     /*!
-      * \brief Returns the maximum peak of grid search.
-      */
+     * \brief Returns the maximum peak of grid search.
+     */
     inline uint32_t mag() const
     {
         return d_mag;
     }
 
     /*!
-      * \brief Initializes acquisition algorithm.
-      */
+     * \brief Initializes acquisition algorithm.
+     */
     void init();
 
     /*!
-      * \brief Sets local code for CCCWSR acquisition algorithm.
-      * \param data_code - Pointer to the data PRN code.
-      * \param pilot_code - Pointer to the pilot PRN code.
-      */
+     * \brief Sets local code for CCCWSR acquisition algorithm.
+     * \param data_code - Pointer to the data PRN code.
+     * \param pilot_code - Pointer to the pilot PRN code.
+     */
     void set_local_code(std::complex<float>* code_data, std::complex<float>* code_pilot);
 
     /*!
-      * \brief Starts acquisition algorithm, turning from standby mode to
-      * active mode
-      * \param active - bool that activates/deactivates the block.
-      */
+     * \brief Starts acquisition algorithm, turning from standby mode to
+     * active mode
+     * \param active - bool that activates/deactivates the block.
+     */
     inline void set_active(bool active)
     {
         d_active = active;
     }
 
     /*!
-      * \brief If set to 1, ensures that acquisition starts at the
-      * first available sample.
-      * \param state - int=1 forces start of acquisition
-      */
+     * \brief If set to 1, ensures that acquisition starts at the
+     * first available sample.
+     * \param state - int=1 forces start of acquisition
+     */
     void set_state(int32_t state);
 
     /*!
-      * \brief Set acquisition channel unique ID
-      * \param channel - receiver channel.
-      */
+     * \brief Set acquisition channel unique ID
+     * \param channel - receiver channel.
+     */
     inline void set_channel(uint32_t channel)
     {
         d_channel = channel;
     }
 
     /*!
-      * \brief Set statistics threshold of CCCWSR algorithm.
-      * \param threshold - Threshold for signal detection (check \ref Navitec2012,
-      * Algorithm 1, for a definition of this threshold).
-      */
+     * \brief Set channel fsm associated to this acquisition instance
+     */
+    inline void set_channel_fsm(std::weak_ptr<ChannelFsm> channel_fsm)
+    {
+        d_channel_fsm = std::move(channel_fsm);
+    }
+
+    /*!
+     * \brief Set statistics threshold of CCCWSR algorithm.
+     * \param threshold - Threshold for signal detection (check \ref Navitec2012,
+     * Algorithm 1, for a definition of this threshold).
+     */
     inline void set_threshold(float threshold)
     {
         d_threshold = threshold;
     }
 
     /*!
-      * \brief Set maximum Doppler grid search
-      * \param doppler_max - Maximum Doppler shift considered in the grid search [Hz].
-      */
+     * \brief Set maximum Doppler grid search
+     * \param doppler_max - Maximum Doppler shift considered in the grid search [Hz].
+     */
     inline void set_doppler_max(uint32_t doppler_max)
     {
         d_doppler_max = doppler_max;
     }
 
     /*!
-      * \brief Set Doppler steps for the grid search
-      * \param doppler_step - Frequency bin of the search grid [Hz].
-      */
+     * \brief Set Doppler steps for the grid search
+     * \param doppler_step - Frequency bin of the search grid [Hz].
+     */
     inline void set_doppler_step(uint32_t doppler_step)
     {
         d_doppler_step = doppler_step;
     }
 
     /*!
-      * \brief Coherent Channel Combining With Sign Recovery Acquisition signal processing.
-      */
+     * \brief Coherent Channel Combining With Sign Recovery Acquisition signal processing.
+     */
     int general_work(int noutput_items, gr_vector_int& ninput_items,
         gr_vector_const_void_star& input_items,
         gr_vector_void_star& output_items);
+
+private:
+    friend pcps_cccwsr_acquisition_cc_sptr
+    pcps_cccwsr_make_acquisition_cc(uint32_t sampled_ms, uint32_t max_dwells,
+        uint32_t doppler_max, int64_t fs_in,
+        int32_t samples_per_ms, int32_t samples_per_code,
+        bool dump, const std::string& dump_filename);
+
+    pcps_cccwsr_acquisition_cc(uint32_t sampled_ms, uint32_t max_dwells,
+        uint32_t doppler_max, int64_t fs_in,
+        int32_t samples_per_ms, int32_t samples_per_code,
+        bool dump, const std::string& dump_filename);
+
+    void calculate_magnitudes(gr_complex* fft_begin, int32_t doppler_shift,
+        int32_t doppler_offset);
+
+    int64_t d_fs_in;
+    int32_t d_samples_per_ms;
+    int32_t d_samples_per_code;
+    uint32_t d_doppler_resolution;
+    float d_threshold;
+    std::string d_satellite_str;
+    uint32_t d_doppler_max;
+    uint32_t d_doppler_step;
+    uint32_t d_sampled_ms;
+    uint32_t d_max_dwells;
+    uint32_t d_well_count;
+    uint32_t d_fft_size;
+    uint64_t d_sample_counter;
+    std::vector<std::vector<gr_complex>> d_grid_doppler_wipeoffs;
+    uint32_t d_num_doppler_bins;
+    std::vector<gr_complex> d_fft_code_data;
+    std::vector<gr_complex> d_fft_code_pilot;
+    std::shared_ptr<gr::fft::fft_complex> d_fft_if;
+    std::shared_ptr<gr::fft::fft_complex> d_ifft;
+    Gnss_Synchro* d_gnss_synchro;
+    uint32_t d_code_phase;
+    float d_doppler_freq;
+    float d_mag;
+    std::vector<float> d_magnitude;
+    std::vector<gr_complex> d_data_correlation;
+    std::vector<gr_complex> d_pilot_correlation;
+    std::vector<gr_complex> d_correlation_plus;
+    std::vector<gr_complex> d_correlation_minus;
+    float d_input_power;
+    float d_test_statistics;
+    std::ofstream d_dump_file;
+    bool d_active;
+    int32_t d_state;
+    bool d_dump;
+    uint32_t d_channel;
+    std::weak_ptr<ChannelFsm> d_channel_fsm;
+    std::string d_dump_filename;
 };
 
-#endif /* GNSS_SDR_PCPS_CCCWSR_ACQUISITION_CC_H_*/
+#endif  // GNSS_SDR_PCPS_CCCWSR_ACQUISITION_CC_H
