@@ -1,56 +1,46 @@
 /*!
-* \file pcps_quicksync_acquisition_cc.h
-* \brief This class implements a Parallel Code Phase Search Acquisition with the
-* QuickSync Algorithm
-*
-*  Acquisition strategy (Kay Borre book CFAR + threshold).
-*  <ol>
-*  <li> Compute the input signal power estimation
-*  <li> Doppler serial search loop
-*  <li> Perform folding of the incoming signal and local generated code
-*  <li> Perform the FFT-based circular convolution (parallel time search)
-*  <li> Record the maximum peak and the associated synchronization parameters
-*  <li> Compute the test statistics and compare to the threshold
-*  <li> Declare positive or negative acquisition using a message port
-*  <li> Obtain the adequate acquisition parameters by correlating the incoming
-*       signal shifted by the possible folded delays
-*  </ol>
-*
-* Kay Borre book: K.Borre, D.M.Akos, N.Bertelsen, P.Rinder, and S.H.Jensen,
-* "A Software-Defined GPS and Galileo Receiver. A Single-Frequency
-* Approach", Birkha user, 2007. pp 81-84
-*
-* \date Jun2 2014
-* \author Damian Miralles Sanchez, dmiralles2009@gmail.com
-*
-* -------------------------------------------------------------------------
-*
-* Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
-*
-* GNSS-SDR is a software defined Global Navigation
-*          Satellite Systems receiver
-*
-* This file is part of GNSS-SDR.
-*
-* GNSS-SDR is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* (at your option) any later version.
-*
-* GNSS-SDR is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
-*
-* -------------------------------------------------------------------------
-*/
+ * \file pcps_quicksync_acquisition_cc.h
+ * \brief This class implements a Parallel Code Phase Search Acquisition with the
+ * QuickSync Algorithm
+ *
+ *  Acquisition strategy (Kay Borre book CFAR + threshold).
+ *  <ol>
+ *  <li> Compute the input signal power estimation
+ *  <li> Doppler serial search loop
+ *  <li> Perform folding of the incoming signal and local generated code
+ *  <li> Perform the FFT-based circular convolution (parallel time search)
+ *  <li> Record the maximum peak and the associated synchronization parameters
+ *  <li> Compute the test statistics and compare to the threshold
+ *  <li> Declare positive or negative acquisition using a message port
+ *  <li> Obtain the adequate acquisition parameters by correlating the incoming
+ *       signal shifted by the possible folded delays
+ *  </ol>
+ *
+ * Kay Borre book: K.Borre, D.M.Akos, N.Bertelsen, P.Rinder, and S.H.Jensen,
+ * "A Software-Defined GPS and Galileo Receiver. A Single-Frequency
+ * Approach", Birkha user, 2007. pp 81-84
+ *
+ * \date Jun2 2014
+ * \author Damian Miralles Sanchez, dmiralles2009@gmail.com
+ *
+ * -------------------------------------------------------------------------
+ *
+ * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
+ *
+ * GNSS-SDR is a software defined Global Navigation
+ *          Satellite Systems receiver
+ *
+ * This file is part of GNSS-SDR.
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ *
+ * -------------------------------------------------------------------------
+ */
 
-#ifndef GNSS_SDR_PCPS_QUICKSYNC_ACQUISITION_CC_H_
-#define GNSS_SDR_PCPS_QUICKSYNC_ACQUISITION_CC_H_
+#ifndef GNSS_SDR_PCPS_QUICKSYNC_ACQUISITION_CC_H
+#define GNSS_SDR_PCPS_QUICKSYNC_ACQUISITION_CC_H
 
+#include "channel_fsm.h"
 #include "gnss_synchro.h"
 #include <gnuradio/block.h>
 #include <gnuradio/fft/fft.h>
@@ -59,15 +49,16 @@
 #include <cassert>
 #include <fstream>
 #include <functional>
+#include <memory>  // for weak_ptr
 #include <string>
+#include <utility>
+#include <vector>
 
 class pcps_quicksync_acquisition_cc;
 
-typedef boost::shared_ptr<pcps_quicksync_acquisition_cc>
-    pcps_quicksync_acquisition_cc_sptr;
+using pcps_quicksync_acquisition_cc_sptr = boost::shared_ptr<pcps_quicksync_acquisition_cc>;
 
-pcps_quicksync_acquisition_cc_sptr
-pcps_quicksync_make_acquisition_cc(
+pcps_quicksync_acquisition_cc_sptr pcps_quicksync_make_acquisition_cc(
     uint32_t folding_factor,
     uint32_t sampled_ms,
     uint32_t max_dwells,
@@ -77,7 +68,7 @@ pcps_quicksync_make_acquisition_cc(
     int32_t samples_per_code,
     bool bit_transition_flag,
     bool dump,
-    std::string dump_filename);
+    const std::string& dump_filename);
 
 /*!
  * \brief This class implements a Parallel Code Phase Search Acquisition with
@@ -88,71 +79,6 @@ pcps_quicksync_make_acquisition_cc(
  */
 class pcps_quicksync_acquisition_cc : public gr::block
 {
-private:
-    friend pcps_quicksync_acquisition_cc_sptr
-    pcps_quicksync_make_acquisition_cc(uint32_t folding_factor,
-        uint32_t sampled_ms, uint32_t max_dwells,
-        uint32_t doppler_max, int64_t fs_in,
-        int32_t samples_per_ms, int32_t samples_per_code,
-        bool bit_transition_flag,
-        bool dump,
-        std::string dump_filename);
-
-    pcps_quicksync_acquisition_cc(uint32_t folding_factor,
-        uint32_t sampled_ms, uint32_t max_dwells,
-        uint32_t doppler_max, int64_t fs_in,
-        int32_t samples_per_ms, int32_t samples_per_code,
-        bool bit_transition_flag,
-        bool dump,
-        std::string dump_filename);
-
-    void calculate_magnitudes(gr_complex* fft_begin, int32_t doppler_shift,
-        int32_t doppler_offset);
-
-    gr_complex* d_code;
-    uint32_t d_folding_factor;  // also referred in the paper as 'p'
-    float* d_corr_acumulator;
-    uint32_t* d_possible_delay;
-    float* d_corr_output_f;
-    float* d_magnitude_folded;
-    gr_complex* d_signal_folded;
-    gr_complex* d_code_folded;
-    float d_noise_floor_power;
-
-    int64_t d_fs_in;
-    int32_t d_samples_per_ms;
-    int32_t d_samples_per_code;
-    uint32_t d_doppler_resolution;
-    float d_threshold;
-    std::string d_satellite_str;
-    uint32_t d_doppler_max;
-    uint32_t d_doppler_step;
-    uint32_t d_sampled_ms;
-    uint32_t d_max_dwells;
-    uint32_t d_well_count;
-    uint32_t d_fft_size;
-    uint64_t d_sample_counter;
-    gr_complex** d_grid_doppler_wipeoffs;
-    uint32_t d_num_doppler_bins;
-    gr_complex* d_fft_codes;
-    gr::fft::fft_complex* d_fft_if;
-    gr::fft::fft_complex* d_fft_if2;
-    gr::fft::fft_complex* d_ifft;
-    Gnss_Synchro* d_gnss_synchro;
-    uint32_t d_code_phase;
-    float d_doppler_freq;
-    float d_mag;
-    float* d_magnitude;
-    float d_input_power;
-    float d_test_statistics;
-    bool d_bit_transition_flag;
-    std::ofstream d_dump_file;
-    bool d_active;
-    int32_t d_state;
-    bool d_dump;
-    uint32_t d_channel;
-    std::string d_dump_filename;
-
 public:
     /*!
      * \brief Default destructor.
@@ -214,6 +140,14 @@ public:
         d_channel = channel;
     }
 
+    /*!
+     * \brief Set channel fsm associated to this acquisition instance
+     */
+    inline void set_channel_fsm(std::weak_ptr<ChannelFsm> channel_fsm)
+    {
+        d_channel_fsm = std::move(channel_fsm);
+    }
+
     /*!
      * \brief Set statistics threshold of PCPS algorithm.
      * \param threshold - Threshold for signal detection (check \ref Navitec2012,
@@ -248,6 +182,69 @@ public:
     int general_work(int noutput_items, gr_vector_int& ninput_items,
         gr_vector_const_void_star& input_items,
         gr_vector_void_star& output_items);
+
+private:
+    friend pcps_quicksync_acquisition_cc_sptr
+    pcps_quicksync_make_acquisition_cc(uint32_t folding_factor,
+        uint32_t sampled_ms, uint32_t max_dwells,
+        uint32_t doppler_max, int64_t fs_in,
+        int32_t samples_per_ms, int32_t samples_per_code,
+        bool bit_transition_flag,
+        bool dump,
+        const std::string& dump_filename);
+
+    pcps_quicksync_acquisition_cc(uint32_t folding_factor,
+        uint32_t sampled_ms, uint32_t max_dwells,
+        uint32_t doppler_max, int64_t fs_in,
+        int32_t samples_per_ms, int32_t samples_per_code,
+        bool bit_transition_flag,
+        bool dump,
+        const std::string& dump_filename);
+
+    void calculate_magnitudes(gr_complex* fft_begin, int32_t doppler_shift,
+        int32_t doppler_offset);
+
+    std::vector<gr_complex> d_code;
+    uint32_t d_folding_factor;  // also referred in the paper as 'p'
+    std::vector<uint32_t> d_possible_delay;
+    std::vector<float> d_corr_output_f;
+    std::vector<float> d_magnitude_folded;
+    std::vector<gr_complex> d_signal_folded;
+    std::vector<gr_complex> d_code_folded;
+    float d_noise_floor_power;
+    int64_t d_fs_in;
+    int32_t d_samples_per_ms;
+    int32_t d_samples_per_code;
+    uint32_t d_doppler_resolution;
+    float d_threshold;
+    std::string d_satellite_str;
+    uint32_t d_doppler_max;
+    uint32_t d_doppler_step;
+    uint32_t d_sampled_ms;
+    uint32_t d_max_dwells;
+    uint32_t d_well_count;
+    uint32_t d_fft_size;
+    uint64_t d_sample_counter;
+    std::vector<std::vector<gr_complex>> d_grid_doppler_wipeoffs;
+    uint32_t d_num_doppler_bins;
+    std::vector<gr_complex> d_fft_codes;
+    std::shared_ptr<gr::fft::fft_complex> d_fft_if;
+    std::shared_ptr<gr::fft::fft_complex> d_ifft;
+    Gnss_Synchro* d_gnss_synchro;
+    uint32_t d_code_phase;
+    float d_doppler_freq;
+    float d_mag;
+    std::vector<float> d_magnitude;
+    float d_input_power;
+    float d_test_statistics;
+    bool d_bit_transition_flag;
+    std::ofstream d_dump_file;
+    bool d_active;
+    int32_t d_state;
+    bool d_dump;
+    uint32_t d_channel;
+    std::weak_ptr<ChannelFsm> d_channel_fsm;
+    std::string d_dump_filename;
 };
 
-#endif /* GNSS_SDR_PCPS_ACQUISITION_CC_H_*/
+#endif  // GNSS_SDR_PCPS_QUICKSYNC_ACQUISITION_CC_H
