@@ -6,25 +6,14 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -------------------------------------------------------------------------
  */
@@ -38,7 +27,6 @@
 #include <volk/volk.h>
 #include <utility>
 
-using google::LogMessage;
 
 FreqXlatingFirFilter::FreqXlatingFirFilter(ConfigurationInterface* configuration, std::string role,
     unsigned int in_streams, unsigned int out_streams) : config_(configuration), role_(std::move(role)), in_streams_(in_streams), out_streams_(out_streams)
@@ -122,32 +110,32 @@ FreqXlatingFirFilter::FreqXlatingFirFilter(ConfigurationInterface* configuration
         }
 
     size_t item_size;
-
+    LOG(INFO) << "Created freq_xlating_fir_filter with " << taps_.size() << " taps";
     if ((taps_item_type_ == "float") && (input_item_type_ == "gr_complex") && (output_item_type_ == "gr_complex"))
         {
-            item_size = sizeof(gr_complex);    //output
-            input_size_ = sizeof(gr_complex);  //input
+            item_size = sizeof(gr_complex);    // output
+            input_size_ = sizeof(gr_complex);  // input
             freq_xlating_fir_filter_ccf_ = gr::filter::freq_xlating_fir_filter_ccf::make(decimation_factor_, taps_, intermediate_freq_, sampling_freq_);
             DLOG(INFO) << "input_filter(" << freq_xlating_fir_filter_ccf_->unique_id() << ")";
         }
     else if ((taps_item_type_ == "float") && (input_item_type_ == "float") && (output_item_type_ == "gr_complex"))
         {
             item_size = sizeof(gr_complex);
-            input_size_ = sizeof(float);  //input
+            input_size_ = sizeof(float);  // input
             freq_xlating_fir_filter_fcf_ = gr::filter::freq_xlating_fir_filter_fcf::make(decimation_factor_, taps_, intermediate_freq_, sampling_freq_);
             DLOG(INFO) << "input_filter(" << freq_xlating_fir_filter_fcf_->unique_id() << ")";
         }
     else if ((taps_item_type_ == "float") && (input_item_type_ == "short") && (output_item_type_ == "gr_complex"))
         {
             item_size = sizeof(gr_complex);
-            input_size_ = sizeof(int16_t);  //input
+            input_size_ = sizeof(int16_t);  // input
             freq_xlating_fir_filter_scf_ = gr::filter::freq_xlating_fir_filter_scf::make(decimation_factor_, taps_, intermediate_freq_, sampling_freq_);
             DLOG(INFO) << "input_filter(" << freq_xlating_fir_filter_scf_->unique_id() << ")";
         }
     else if ((taps_item_type_ == "float") && (input_item_type_ == "short") && (output_item_type_ == "cshort"))
         {
             item_size = sizeof(lv_16sc_t);
-            input_size_ = sizeof(int16_t);  //input
+            input_size_ = sizeof(int16_t);  // input
             freq_xlating_fir_filter_scf_ = gr::filter::freq_xlating_fir_filter_scf::make(decimation_factor_, taps_, intermediate_freq_, sampling_freq_);
             DLOG(INFO) << "input_filter(" << freq_xlating_fir_filter_scf_->unique_id() << ")";
             complex_to_float_ = gr::blocks::complex_to_float::make();
@@ -158,7 +146,7 @@ FreqXlatingFirFilter::FreqXlatingFirFilter(ConfigurationInterface* configuration
     else if ((taps_item_type_ == "float") && (input_item_type_ == "byte") && (output_item_type_ == "gr_complex"))
         {
             item_size = sizeof(gr_complex);
-            input_size_ = sizeof(int8_t);  //input
+            input_size_ = sizeof(int8_t);  // input
             gr_char_to_short_ = gr::blocks::char_to_short::make();
             freq_xlating_fir_filter_scf_ = gr::filter::freq_xlating_fir_filter_scf::make(decimation_factor_, taps_, intermediate_freq_, sampling_freq_);
             DLOG(INFO) << "input_filter(" << freq_xlating_fir_filter_scf_->unique_id() << ")";
@@ -166,7 +154,7 @@ FreqXlatingFirFilter::FreqXlatingFirFilter(ConfigurationInterface* configuration
     else if ((taps_item_type_ == "float") && (input_item_type_ == "byte") && (output_item_type_ == "cbyte"))
         {
             item_size = sizeof(lv_8sc_t);
-            input_size_ = sizeof(int8_t);  //input
+            input_size_ = sizeof(int8_t);  // input
             gr_char_to_short_ = gr::blocks::char_to_short::make();
             freq_xlating_fir_filter_scf_ = gr::filter::freq_xlating_fir_filter_scf::make(decimation_factor_, taps_, intermediate_freq_, sampling_freq_);
             DLOG(INFO) << "input_filter(" << freq_xlating_fir_filter_scf_->unique_id() << ")";
@@ -175,8 +163,8 @@ FreqXlatingFirFilter::FreqXlatingFirFilter(ConfigurationInterface* configuration
     else
         {
             LOG(ERROR) << " Unknown input filter input/output item type conversion";
-            item_size = sizeof(gr_complex);    //avoids uninitialization
-            input_size_ = sizeof(gr_complex);  //avoids uninitialization
+            item_size = sizeof(gr_complex);    // avoids uninitialization
+            input_size_ = sizeof(gr_complex);  // avoids uninitialization
         }
 
     if (dump_)
@@ -196,9 +184,6 @@ FreqXlatingFirFilter::FreqXlatingFirFilter(ConfigurationInterface* configuration
 }
 
 
-FreqXlatingFirFilter::~FreqXlatingFirFilter() = default;
-
-
 void FreqXlatingFirFilter::connect(gr::top_block_sptr top_block)
 {
     if ((taps_item_type_ == "float") && (input_item_type_ == "gr_complex") && (output_item_type_ == "gr_complex"))
@@ -339,15 +324,13 @@ gr::basic_block_sptr FreqXlatingFirFilter::get_left_block()
         {
             return gr_char_to_short_;
         }
-    else if ((taps_item_type_ == "float") && (input_item_type_ == "byte") && (output_item_type_ == "cbyte"))
+    if ((taps_item_type_ == "float") && (input_item_type_ == "byte") && (output_item_type_ == "cbyte"))
         {
             return gr_char_to_short_;
         }
-    else
-        {
-            return nullptr;
-            LOG(ERROR) << " Unknown input filter input/output item type conversion";
-        }
+
+    LOG(WARNING) << " Unknown input filter input/output item type conversion";
+    return nullptr;
 }
 
 
@@ -373,13 +356,11 @@ gr::basic_block_sptr FreqXlatingFirFilter::get_right_block()
         {
             return freq_xlating_fir_filter_scf_;
         }
-    else if ((taps_item_type_ == "float") && (input_item_type_ == "byte") && (output_item_type_ == "cbyte"))
+    if ((taps_item_type_ == "float") && (input_item_type_ == "byte") && (output_item_type_ == "cbyte"))
         {
             return complex_to_complex_byte_;
         }
-    else
-        {
-            return nullptr;
-            LOG(ERROR) << " Unknown input filter input/output item type conversion";
-        }
+
+    LOG(WARNING) << " Unknown input filter input/output item type conversion";
+    return nullptr;
 }
