@@ -25,28 +25,7 @@
  * Copyright (C) 2017, Carles Fernandez
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are
- * met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * SPDX-License-Identifier: BSD-2-Clause
  *
  *----------------------------------------------------------------------------*/
 
@@ -75,7 +54,7 @@ const double ERREPH_GLO = 5.0;    /* error of glonass ephemeris (m) */
 const double TSTEP = 60.0;        /* integration step glonass ephemeris (s) */
 const double RTOL_KEPLER = 1e-13; /* relative tolerance for Kepler equation */
 
-const double DEFURASSR = 0.15;                   /* default accurary of ssr corr (m) */
+const double DEFURASSR = 0.15;                   /* default accuracy of ssr corr (m) */
 const double MAXECORSSR = 10.0;                  /* max orbit correction of ssr (m) */
 const double MAXCCORSSR = 1e-6 * SPEED_OF_LIGHT; /* max clock correction of ssr (m) */
 const double MAXAGESSR = 90.0;                   /* max age of ssr orbit and clock (s) */
@@ -99,8 +78,14 @@ double var_uraeph(int ura)
 double var_urassr(int ura)
 {
     double std_;
-    if (ura <= 0) return std::pow(DEFURASSR, 2.0);
-    if (ura >= 63) return std::pow(5.4665, 2.0);
+    if (ura <= 0)
+        {
+            return std::pow(DEFURASSR, 2.0);
+        }
+    if (ura >= 63)
+        {
+            return std::pow(5.4665, 2.0);
+        }
     std_ = (std::pow((ura >> 3) & 7, 2.0) * (1.0 + (ura & 7) / 4.0) - 1.0) * 1e-3;
     return std::pow(std_, 2.0);
 }
@@ -117,12 +102,27 @@ double var_urassr(int ura)
  *-----------------------------------------------------------------------------*/
 void alm2pos(gtime_t time, const alm_t *alm, double *rs, double *dts)
 {
-    double tk, M, E, Ek, sinE, cosE, u, r, i, O, x, y, sinO, cosO, cosi, mu;
+    double tk;
+    double M;
+    double E;
+    double Ek;
+    double sinE;
+    double cosE;
+    double u;
+    double r;
+    double i;
+    double O;
+    double x;
+    double y;
+    double sinO;
+    double cosO;
+    double cosi;
+    double mu;
     int n;
 
     trace(4, "alm2pos : time=%s sat=%2d\n", time_str(time, 3), alm->sat);
 
-    tk = timediff(time, alm->toa);
+    tk = timediffweekcrossover(time, alm->toa);
 
     if (alm->A <= 0.0)
         {
@@ -175,7 +175,7 @@ double eph2clk(gtime_t time, const eph_t *eph)
 
     trace(4, "eph2clk : time=%s sat=%2d\n", time_str(time, 3), eph->sat);
 
-    t = timediff(time, eph->toc);
+    t = timediffweekcrossover(time, eph->toc);
 
     for (i = 0; i < 2; i++)
         {
@@ -201,9 +201,33 @@ double eph2clk(gtime_t time, const eph_t *eph)
 void eph2pos(gtime_t time, const eph_t *eph, double *rs, double *dts,
     double *var)
 {
-    double tk, M, E, Ek, sinE, cosE, u, r, i, O, sin2u, cos2u, x, y, sinO, cosO, cosi, mu, omge;
-    double xg, yg, zg, sino, coso;
-    int n, sys, prn;
+    double tk;
+    double M;
+    double E;
+    double Ek;
+    double sinE;
+    double cosE;
+    double u;
+    double r;
+    double i;
+    double O;
+    double sin2u;
+    double cos2u;
+    double x;
+    double y;
+    double sinO;
+    double cosO;
+    double cosi;
+    double mu;
+    double omge;
+    double xg;
+    double yg;
+    double zg;
+    double sino;
+    double coso;
+    int n;
+    int sys;
+    int prn;
 
     trace(4, "eph2pos : time=%s sat=%2d\n", time_str(time, 3), eph->sat);
 
@@ -212,7 +236,7 @@ void eph2pos(gtime_t time, const eph_t *eph, double *rs, double *dts,
             rs[0] = rs[1] = rs[2] = *dts = *var = 0.0;
             return;
         }
-    tk = timediff(time, eph->toe);
+    tk = timediffweekcrossover(time, eph->toe);
 
     switch ((sys = satsys(eph->sat, &prn)))
         {
@@ -282,7 +306,7 @@ void eph2pos(gtime_t time, const eph_t *eph, double *rs, double *dts,
             rs[1] = x * sinO + y * cosi * cosO;
             rs[2] = y * sin(i);
         }
-    tk = timediff(time, eph->toc);
+    tk = timediffweekcrossover(time, eph->toc);
     *dts = eph->f0 + eph->f1 * tk + eph->f2 * tk * tk;
 
     /* relativity correction */
@@ -296,7 +320,12 @@ void eph2pos(gtime_t time, const eph_t *eph, double *rs, double *dts,
 /* glonass orbit differential equations --------------------------------------*/
 void deq(const double *x, double *xdot, const double *acc)
 {
-    double a, b, c, r2 = dot(x, x, 3), r3 = r2 * sqrt(r2), omg2 = std::pow(OMGE_GLO, 2.0);
+    double a;
+    double b;
+    double c;
+    double r2 = dot(x, x, 3);
+    double r3 = r2 * sqrt(r2);
+    double omg2 = std::pow(OMGE_GLO, 2.0);
 
     if (r2 <= 0.0)
         {
@@ -319,17 +348,33 @@ void deq(const double *x, double *xdot, const double *acc)
 /* glonass position and velocity by numerical integration --------------------*/
 void glorbit(double t, double *x, const double *acc)
 {
-    double k1[6], k2[6], k3[6], k4[6], w[6];
+    double k1[6];
+    double k2[6];
+    double k3[6];
+    double k4[6];
+    double w[6];
     int i;
 
     deq(x, k1, acc);
-    for (i = 0; i < 6; i++) w[i] = x[i] + k1[i] * t / 2.0;
+    for (i = 0; i < 6; i++)
+        {
+            w[i] = x[i] + k1[i] * t / 2.0;
+        }
     deq(w, k2, acc);
-    for (i = 0; i < 6; i++) w[i] = x[i] + k2[i] * t / 2.0;
+    for (i = 0; i < 6; i++)
+        {
+            w[i] = x[i] + k2[i] * t / 2.0;
+        }
     deq(w, k3, acc);
-    for (i = 0; i < 6; i++) w[i] = x[i] + k3[i] * t;
+    for (i = 0; i < 6; i++)
+        {
+            w[i] = x[i] + k3[i] * t;
+        }
     deq(w, k4, acc);
-    for (i = 0; i < 6; i++) x[i] += (k1[i] + 2.0 * k2[i] + 2.0 * k3[i] + k4[i]) * t / 6.0;
+    for (i = 0; i < 6; i++)
+        {
+            x[i] += (k1[i] + 2.0 * k2[i] + 2.0 * k3[i] + k4[i]) * t / 6.0;
+        }
 }
 
 
@@ -370,7 +415,9 @@ double geph2clk(gtime_t time, const geph_t *geph)
 void geph2pos(gtime_t time, const geph_t *geph, double *rs, double *dts,
     double *var)
 {
-    double t, tt, x[6];
+    double t;
+    double tt;
+    double x[6];
     int i;
 
     trace(4, "geph2pos: time=%s sat=%2d\n", time_str(time, 3), geph->sat);
@@ -384,12 +431,20 @@ void geph2pos(gtime_t time, const geph_t *geph, double *rs, double *dts,
             x[i] = geph->pos[i];
             x[i + 3] = geph->vel[i];
         }
-    for (tt = t < 0.0 ? -TSTEP : TSTEP; fabs(t) > 1e-9; t -= tt)
+    tt = t < 0.0 ? -TSTEP : TSTEP;
+    while (fabs(t) > 1e-9)
         {
-            if (fabs(t) < TSTEP) tt = t;
+            if (fabs(t) < TSTEP)
+                {
+                    tt = t;
+                }
             glorbit(tt, x, geph->acc);
+            t -= tt;
+        }
+    for (i = 0; i < 3; i++)
+        {
+            rs[i] = x[i];
         }
-    for (i = 0; i < 3; i++) rs[i] = x[i];
 
     *var = std::pow(ERREPH_GLO, 2.0);
 }
@@ -409,7 +464,7 @@ double seph2clk(gtime_t time, const seph_t *seph)
 
     trace(4, "seph2clk: time=%s sat=%2d\n", time_str(time, 3), seph->sat);
 
-    t = timediff(time, seph->t0);
+    t = timediffweekcrossover(time, seph->t0);
 
     for (i = 0; i < 2; i++)
         {
@@ -437,7 +492,7 @@ void seph2pos(gtime_t time, const seph_t *seph, double *rs, double *dts,
 
     trace(4, "seph2pos: time=%s sat=%2d\n", time_str(time, 3), seph->sat);
 
-    t = timediff(time, seph->t0);
+    t = timediffweekcrossover(time, seph->t0);
 
     for (i = 0; i < 3; i++)
         {
@@ -449,11 +504,14 @@ void seph2pos(gtime_t time, const seph_t *seph, double *rs, double *dts,
 }
 
 
-/* select ephememeris --------------------------------------------------------*/
+/* select ephemeris --------------------------------------------------------*/
 eph_t *seleph(gtime_t time, int sat, int iode, const nav_t *nav)
 {
-    double t, tmax, tmin;
-    int i, j = -1;
+    double t;
+    double tmax;
+    double tmin;
+    int i;
+    int j = -1;
 
     trace(4, "seleph  : time=%s sat=%2d iode=%d\n", time_str(time, 3), sat, iode);
 
@@ -476,10 +534,22 @@ eph_t *seleph(gtime_t time, int sat, int iode, const nav_t *nav)
 
     for (i = 0; i < nav->n; i++)
         {
-            if (nav->eph[i].sat != sat) continue;
-            if (iode >= 0 && nav->eph[i].iode != iode) continue;
-            if ((t = fabs(timediff(nav->eph[i].toe, time))) > tmax) continue;
-            if (iode >= 0) return nav->eph + i;
+            if (nav->eph[i].sat != sat)
+                {
+                    continue;
+                }
+            if (iode >= 0 && nav->eph[i].iode != iode)
+                {
+                    continue;
+                }
+            if ((t = fabs(timediffweekcrossover(nav->eph[i].toe, time))) > tmax)
+                {
+                    continue;
+                }
+            if (iode >= 0)
+                {
+                    return nav->eph + i;
+                }
             if (t <= tmin)
                 {
                     j = i;
@@ -496,20 +566,35 @@ eph_t *seleph(gtime_t time, int sat, int iode, const nav_t *nav)
 }
 
 
-/* select glonass ephememeris ------------------------------------------------*/
+/* select glonass ephemeris ------------------------------------------------*/
 geph_t *selgeph(gtime_t time, int sat, int iode, const nav_t *nav)
 {
-    double t, tmax = MAXDTOE_GLO, tmin = tmax + 1.0;
-    int i, j = -1;
+    double t;
+    double tmax = MAXDTOE_GLO;
+    double tmin = tmax + 1.0;
+    int i;
+    int j = -1;
 
     trace(4, "selgeph : time=%s sat=%2d iode=%2d\n", time_str(time, 3), sat, iode);
 
     for (i = 0; i < nav->ng; i++)
         {
-            if (nav->geph[i].sat != sat) continue;
-            if (iode >= 0 && nav->geph[i].iode != iode) continue;
-            if ((t = fabs(timediff(nav->geph[i].toe, time))) > tmax) continue;
-            if (iode >= 0) return nav->geph + i;
+            if (nav->geph[i].sat != sat)
+                {
+                    continue;
+                }
+            if (iode >= 0 && nav->geph[i].iode != iode)
+                {
+                    continue;
+                }
+            if ((t = fabs(timediff(nav->geph[i].toe, time))) > tmax)
+                {
+                    continue;
+                }
+            if (iode >= 0)
+                {
+                    return nav->geph + i;
+                }
             if (t <= tmin)
                 {
                     j = i;
@@ -526,18 +611,27 @@ geph_t *selgeph(gtime_t time, int sat, int iode, const nav_t *nav)
 }
 
 
-/* select sbas ephememeris ---------------------------------------------------*/
+/* select sbas ephemeris ---------------------------------------------------*/
 seph_t *selseph(gtime_t time, int sat, const nav_t *nav)
 {
-    double t, tmax = MAXDTOE_SBS, tmin = tmax + 1.0;
-    int i, j = -1;
+    double t;
+    double tmax = MAXDTOE_SBS;
+    double tmin = tmax + 1.0;
+    int i;
+    int j = -1;
 
     trace(4, "selseph : time=%s sat=%2d\n", time_str(time, 3), sat);
 
     for (i = 0; i < nav->ns; i++)
         {
-            if (nav->seph[i].sat != sat) continue;
-            if ((t = fabs(timediff(nav->seph[i].t0, time))) > tmax) continue;
+            if (nav->seph[i].sat != sat)
+                {
+                    continue;
+                }
+            if ((t = fabs(timediffweekcrossover(nav->seph[i].t0, time))) > tmax)
+                {
+                    continue;
+                }
             if (t <= tmin)
                 {
                     j = i;
@@ -568,21 +662,32 @@ int ephclk(gtime_t time, gtime_t teph, int sat, const nav_t *nav,
 
     if (sys == SYS_GPS || sys == SYS_GAL || sys == SYS_QZS || sys == SYS_BDS)
         {
-            if (!(eph = seleph(teph, sat, -1, nav))) return 0;
+            if (!(eph = seleph(teph, sat, -1, nav)))
+                {
+                    return 0;
+                }
             *dts = eph2clk(time, eph);
         }
     else if (sys == SYS_GLO)
         {
-            if (!(geph = selgeph(teph, sat, -1, nav))) return 0;
+            if (!(geph = selgeph(teph, sat, -1, nav)))
+                {
+                    return 0;
+                }
             *dts = geph2clk(time, geph);
         }
     else if (sys == SYS_SBS)
         {
-            if (!(seph = selseph(teph, sat, nav))) return 0;
+            if (!(seph = selseph(teph, sat, nav)))
+                {
+                    return 0;
+                }
             *dts = seph2clk(time, seph);
         }
     else
-        return 0;
+        {
+            return 0;
+        }
 
     return 1;
 }
@@ -595,8 +700,11 @@ int ephpos(gtime_t time, gtime_t teph, int sat, const nav_t *nav,
     eph_t *eph;
     geph_t *geph;
     seph_t *seph;
-    double rst[3], dtst[1], tt = 1e-3;
-    int i, sys;
+    double rst[3];
+    double dtst[1];
+    double tt = 1e-3;
+    int i;
+    int sys;
 
     trace(4, "ephpos  : time=%s sat=%2d iode=%d\n", time_str(time, 3), sat, iode);
 
@@ -606,7 +714,10 @@ int ephpos(gtime_t time, gtime_t teph, int sat, const nav_t *nav,
 
     if (sys == SYS_GPS || sys == SYS_GAL || sys == SYS_QZS || sys == SYS_BDS)
         {
-            if (!(eph = seleph(teph, sat, iode, nav))) return 0;
+            if (!(eph = seleph(teph, sat, iode, nav)))
+                {
+                    return 0;
+                }
 
             eph2pos(time, eph, rs, dts, var);
             time = timeadd(time, tt);
@@ -615,7 +726,10 @@ int ephpos(gtime_t time, gtime_t teph, int sat, const nav_t *nav,
         }
     else if (sys == SYS_GLO)
         {
-            if (!(geph = selgeph(teph, sat, iode, nav))) return 0;
+            if (!(geph = selgeph(teph, sat, iode, nav)))
+                {
+                    return 0;
+                }
             geph2pos(time, geph, rs, dts, var);
             time = timeadd(time, tt);
             geph2pos(time, geph, rst, dtst, var);
@@ -623,7 +737,10 @@ int ephpos(gtime_t time, gtime_t teph, int sat, const nav_t *nav,
         }
     else if (sys == SYS_SBS)
         {
-            if (!(seph = selseph(teph, sat, nav))) return 0;
+            if (!(seph = selseph(teph, sat, nav)))
+                {
+                    return 0;
+                }
 
             seph2pos(time, seph, rs, dts, var);
             time = timeadd(time, tt);
@@ -631,10 +748,15 @@ int ephpos(gtime_t time, gtime_t teph, int sat, const nav_t *nav,
             *svh = seph->svh;
         }
     else
-        return 0;
+        {
+            return 0;
+        }
 
     /* satellite velocity and clock drift by differential approx */
-    for (i = 0; i < 3; i++) rs[i + 3] = (rst[i] - rs[i]) / tt;
+    for (i = 0; i < 3; i++)
+        {
+            rs[i + 3] = (rst[i] - rs[i]) / tt;
+        }
     dts[1] = (dtst[0] - dts[0]) / tt;
 
     return 1;
@@ -654,7 +776,10 @@ int satpos_sbas(gtime_t time, gtime_t teph, int sat, const nav_t *nav,
     for (i = 0; i < nav->sbssat.nsat; i++)
         {
             sbs = nav->sbssat.sat + i;
-            if (sbs->sat == sat) break;
+            if (sbs->sat == sat)
+                {
+                    break;
+                }
         }
     if (i >= nav->sbssat.nsat)
         {
@@ -664,10 +789,16 @@ int satpos_sbas(gtime_t time, gtime_t teph, int sat, const nav_t *nav,
             return 0;
         }
     /* satellite position and clock by broadcast ephemeris */
-    if (!ephpos(time, teph, sat, nav, sbs->lcorr.iode, rs, dts, var, svh)) return 0;
+    if (!ephpos(time, teph, sat, nav, sbs->lcorr.iode, rs, dts, var, svh))
+        {
+            return 0;
+        }
 
     /* sbas satellite correction (long term and fast) */
-    if (sbssatcorr(time, sat, nav, rs, dts, var)) return 1;
+    if (sbssatcorr(time, sat, nav, rs, dts, var))
+        {
+            return 1;
+        }
     *svh = -1;
     return 0;
 }
@@ -679,8 +810,19 @@ int satpos_ssr(gtime_t time, gtime_t teph, int sat, const nav_t *nav,
 {
     const ssr_t *ssr;
     eph_t *eph;
-    double t1, t2, t3, er[3], ea[3], ec[3], rc[3], deph[3], dclk, dant[3] = {0}, tk;
-    int i, sys;
+    double t1;
+    double t2;
+    double t3;
+    double er[3];
+    double ea[3];
+    double ec[3];
+    double rc[3];
+    double deph[3];
+    double dclk;
+    double dant[3] = {0};
+    double tk;
+    int i;
+    int sys;
 
     trace(4, "satpos_ssr: time=%s sat=%2d\n", time_str(time, 3), sat);
 
@@ -704,9 +846,9 @@ int satpos_ssr(gtime_t time, gtime_t teph, int sat, const nav_t *nav,
             *svh = -1;
             return 0;
         }
-    t1 = timediff(time, ssr->t0[0]);
-    t2 = timediff(time, ssr->t0[1]);
-    t3 = timediff(time, ssr->t0[2]);
+    t1 = timediffweekcrossover(time, ssr->t0[0]);
+    t2 = timediffweekcrossover(time, ssr->t0[1]);
+    t3 = timediffweekcrossover(time, ssr->t0[2]);
 
     /* ssr orbit and clock correction (ref [4]) */
     if (fabs(t1) > MAXAGESSR || fabs(t2) > MAXAGESSR)
@@ -716,10 +858,19 @@ int satpos_ssr(gtime_t time, gtime_t teph, int sat, const nav_t *nav,
             *svh = -1;
             return 0;
         }
-    if (ssr->udi[0] >= 1.0) t1 -= ssr->udi[0] / 2.0;
-    if (ssr->udi[1] >= 1.0) t2 -= ssr->udi[0] / 2.0;
+    if (ssr->udi[0] >= 1.0)
+        {
+            t1 -= ssr->udi[0] / 2.0;
+        }
+    if (ssr->udi[1] >= 1.0)
+        {
+            t2 -= ssr->udi[0] / 2.0;
+        }
 
-    for (i = 0; i < 3; i++) deph[i] = ssr->deph[i] + ssr->ddeph[i] * t1;
+    for (i = 0; i < 3; i++)
+        {
+            deph[i] = ssr->deph[i] + ssr->ddeph[i] * t1;
+        }
     dclk = ssr->dclk[0] + ssr->dclk[1] * t2 + ssr->dclk[2] * t2 * t2;
 
     /* ssr highrate clock correction (ref [4]) */
@@ -735,16 +886,22 @@ int satpos_ssr(gtime_t time, gtime_t teph, int sat, const nav_t *nav,
             return 0;
         }
     /* satellite position and clock by broadcast ephemeris */
-    if (!ephpos(time, teph, sat, nav, ssr->iode, rs, dts, var, svh)) return 0;
+    if (!ephpos(time, teph, sat, nav, ssr->iode, rs, dts, var, svh))
+        {
+            return 0;
+        }
 
     /* satellite clock for gps, galileo and qzss */
     sys = satsys(sat, nullptr);
     if (sys == SYS_GPS || sys == SYS_GAL || sys == SYS_QZS || sys == SYS_BDS)
         {
-            if (!(eph = seleph(teph, sat, ssr->iode, nav))) return 0;
+            if (!(eph = seleph(teph, sat, ssr->iode, nav)))
+                {
+                    return 0;
+                }
 
             /* satellite clock by clock parameters */
-            tk = timediff(time, eph->toc);
+            tk = timediffweekcrossover(time, eph->toc);
             dts[0] = eph->f0 + eph->f1 * tk + eph->f2 * tk * tk;
             dts[1] = eph->f1 + 2.0 * eph->f2 * tk;
 
@@ -752,7 +909,10 @@ int satpos_ssr(gtime_t time, gtime_t teph, int sat, const nav_t *nav,
             dts[0] -= 2.0 * dot(rs, rs + 3, 3) / SPEED_OF_LIGHT / SPEED_OF_LIGHT;
         }
     /* radial-along-cross directions in ecef */
-    if (!normv3(rs + 3, ea)) return 0;
+    if (!normv3(rs + 3, ea))
+        {
+            return 0;
+        }
     cross3(rs, rs + 3, rc);
     if (!normv3(rc, ec))
         {
@@ -819,11 +979,15 @@ int satpos(gtime_t time, gtime_t teph, int sat, int ephopt,
             return satpos_ssr(time, teph, sat, nav, 1, rs, dts, var, svh);
         case EPHOPT_PREC:
             if (!peph2pos(time, sat, nav, 1, rs, dts, var))
-                break;
+                {
+                    break;
+                }
             else
-                return 1;
-            //TODO: enable lex
-            //case EPHOPT_LEX   :
+                {
+                    return 1;
+                }
+            // TODO: enable lex
+            // case EPHOPT_LEX   :
             //    if (!lexeph2pos(time, sat, nav, rs, dts, var)) break; else return 1;
         }
     *svh = -1;
@@ -859,21 +1023,34 @@ void satposs(gtime_t teph, const obsd_t *obs, int n, const nav_t *nav,
     int ephopt, double *rs, double *dts, double *var, int *svh)
 {
     gtime_t time[MAXOBS] = {};
-    double dt, pr;
-    int i, j;
+    double dt;
+    double pr;
+    int i;
+    int j;
 
     trace(3, "satposs : teph=%s n=%d ephopt=%d\n", time_str(teph, 3), n, ephopt);
 
     for (i = 0; i < n && i < MAXOBS; i++)
         {
-            for (j = 0; j < 6; j++) rs[j + i * 6] = 0.0;
-            for (j = 0; j < 2; j++) dts[j + i * 2] = 0.0;
+            for (j = 0; j < 6; j++)
+                {
+                    rs[j + i * 6] = 0.0;
+                }
+            for (j = 0; j < 2; j++)
+                {
+                    dts[j + i * 2] = 0.0;
+                }
             var[i] = 0.0;
             svh[i] = 0;
 
             /* search any pseudorange */
             for (j = 0, pr = 0.0; j < NFREQ; j++)
-                if ((pr = obs[i].P[j]) != 0.0) break;
+                {
+                    if ((pr = obs[i].P[j]) != 0.0)
+                        {
+                            break;
+                        }
+                }
 
             if (j >= NFREQ)
                 {
@@ -901,7 +1078,10 @@ void satposs(gtime_t teph, const obsd_t *obs, int n, const nav_t *nav,
             /* if no precise clock available, use broadcast clock instead */
             if (dts[i * 2] == 0.0)
                 {
-                    if (!ephclk(time[i], teph, obs[i].sat, nav, dts + i * 2)) continue;
+                    if (!ephclk(time[i], teph, obs[i].sat, nav, dts + i * 2))
+                        {
+                            continue;
+                        }
                     dts[1 + i * 2] = 0.0;
                     *var = std::pow(STD_BRDCCLK, 2.0);
                 }
