@@ -8,37 +8,25 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -------------------------------------------------------------------------
  */
 
 
 #include "direct_resampler_conditioner_cb.h"
-#include <glog/logging.h>
 #include <gnuradio/io_signature.h>
+#include <volk/volk.h>  // for lv_8sc_t
+#include <algorithm>    // for min
 
 
-using google::LogMessage;
-
 direct_resampler_conditioner_cb_sptr direct_resampler_make_conditioner_cb(
     double sample_freq_in, double sample_freq_out)
 {
@@ -73,9 +61,6 @@ direct_resampler_conditioner_cb::direct_resampler_conditioner_cb(
 }
 
 
-direct_resampler_conditioner_cb::~direct_resampler_conditioner_cb() = default;
-
-
 void direct_resampler_conditioner_cb::forecast(int noutput_items,
     gr_vector_int &ninput_items_required)
 {
