@@ -6,25 +6,14 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -------------------------------------------------------------------------
  */
@@ -41,17 +30,14 @@
 #include <utility>
 
 
-using google::LogMessage;
-
-
 TwoBitCpxFileSignalSource::TwoBitCpxFileSignalSource(ConfigurationInterface* configuration,
     const std::string& role,
     unsigned int in_streams,
     unsigned int out_streams,
-    boost::shared_ptr<gr::msg_queue> queue) : role_(role),
-                                              in_streams_(in_streams),
-                                              out_streams_(out_streams),
-                                              queue_(std::move(queue))
+    const std::shared_ptr<Concurrent_Queue<pmt::pmt_t>>& queue) : role_(role),
+                                                                  in_streams_(in_streams),
+                                                                  out_streams_(out_streams),
+                                                                  queue_(queue)
 {
     std::string default_filename = "../data/my_capture.dat";
     std::string default_item_type = "byte";
@@ -62,8 +48,14 @@ TwoBitCpxFileSignalSource::TwoBitCpxFileSignalSource(ConfigurationInterface* con
     filename_ = configuration->property(role + ".filename", default_filename);
 
     // override value with commandline flag, if present
-    if (FLAGS_signal_source != "-") filename_ = FLAGS_signal_source;
-    if (FLAGS_s != "-") filename_ = FLAGS_s;
+    if (FLAGS_signal_source != "-")
+        {
+            filename_ = FLAGS_signal_source;
+        }
+    if (FLAGS_s != "-")
+        {
+            filename_ = FLAGS_s;
+        }
 
     item_type_ = configuration->property(role + ".item_type", default_item_type);
     repeat_ = configuration->property(role + ".repeat", false);
@@ -84,7 +76,7 @@ TwoBitCpxFileSignalSource::TwoBitCpxFileSignalSource(ConfigurationInterface* con
         {
             file_source_ = gr::blocks::file_source::make(item_size_, filename_.c_str(), repeat_);
             unpack_byte_ = make_unpack_byte_2bit_cpx_samples();
-            inter_shorts_to_cpx_ = gr::blocks::interleaved_short_to_complex::make(false, true);  //I/Q swap enabled
+            inter_shorts_to_cpx_ = gr::blocks::interleaved_short_to_complex::make(false, true);  // I/Q swap enabled
         }
     catch (const std::exception& e)
         {
@@ -140,7 +132,7 @@ TwoBitCpxFileSignalSource::TwoBitCpxFileSignalSource(ConfigurationInterface* con
                 {
                     int sample_packet_factor = 2;  // 1 byte -> 2 samples
                     samples_ = floor(static_cast<double>(size) / static_cast<double>(item_size())) * sample_packet_factor;
-                    samples_ = samples_ - ceil(0.002 * static_cast<double>(sampling_frequency_));  //process all the samples available in the file excluding the last 2 ms
+                    samples_ = samples_ - ceil(0.002 * static_cast<double>(sampling_frequency_));  // process all the samples available in the file excluding the last 2 ms
                 }
         }
 
@@ -155,7 +147,7 @@ TwoBitCpxFileSignalSource::TwoBitCpxFileSignalSource(ConfigurationInterface* con
 
     if (dump_)
         {
-            //sink_ = gr_make_file_sink(item_size_, dump_filename_.c_str());
+            // sink_ = gr_make_file_sink(item_size_, dump_filename_.c_str());
             sink_ = gr::blocks::file_sink::make(sizeof(gr_complex), dump_filename_.c_str());
             DLOG(INFO) << "file_sink(" << sink_->unique_id() << ")";
         }
@@ -183,9 +175,6 @@ TwoBitCpxFileSignalSource::TwoBitCpxFileSignalSource(ConfigurationInterface* con
 }
 
 
-TwoBitCpxFileSignalSource::~TwoBitCpxFileSignalSource() = default;
-
-
 void TwoBitCpxFileSignalSource::connect(gr::top_block_sptr top_block)
 {
     if (samples_ > 0)
@@ -307,7 +296,7 @@ void TwoBitCpxFileSignalSource::disconnect(gr::top_block_sptr top_block)
 gr::basic_block_sptr TwoBitCpxFileSignalSource::get_left_block()
 {
     LOG(WARNING) << "Left block of a signal source should not be retrieved";
-    //return gr_block_sptr();
+    // return gr_block_sptr();
     return gr::blocks::file_source::sptr();
 }
 
