@@ -9,31 +9,20 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -------------------------------------------------------------------------
  */
 
-#ifndef GNSS_SDR_CONFIGURATION_INTERFACE_H_
-#define GNSS_SDR_CONFIGURATION_INTERFACE_H_
+#ifndef GNSS_SDR_CONFIGURATION_INTERFACE_H
+#define GNSS_SDR_CONFIGURATION_INTERFACE_H
 
 #include <cstdint>
 #include <string>
@@ -66,4 +55,4 @@ public:
     virtual void set_property(std::string property_name, std::string value) = 0;
 };
 
-#endif /*GNSS_SDR_CONFIGURATION_INTERFACE_H_*/
+#endif  // GNSS_SDR_CONFIGURATION_INTERFACE_H
