@@ -5,25 +5,14 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -------------------------------------------------------------------------
  */
@@ -31,8 +20,11 @@
 #ifndef GNSS_SDR_CONCURRENT_QUEUE_H
 #define GNSS_SDR_CONCURRENT_QUEUE_H
 
-#include <boost/thread.hpp>
+#include <chrono>
+#include <condition_variable>
+#include <mutex>
 #include <queue>
+#include <thread>
 
 template <typename Data>
 
@@ -41,19 +33,14 @@ template <typename Data>
  *
  * Thread-safe object queue which uses the library
  * boost_thread to perform MUTEX based on the code available at
- * http://www.justsoftwaresolutions.co.uk/threading/implementing-a-thread-safe-queue-using-condition-variables.html
+ * https://www.justsoftwaresolutions.co.uk/threading/implementing-a-thread-safe-queue-using-condition-variables.html
  */
-class concurrent_queue
+class Concurrent_Queue
 {
-private:
-    std::queue<Data> the_queue;
-    mutable boost::mutex the_mutex;
-    boost::condition_variable the_condition_variable;
-
 public:
     void push(Data const& data)
     {
-        boost::mutex::scoped_lock lock(the_mutex);
+        std::unique_lock<std::mutex> lock(the_mutex);
         the_queue.push(data);
         lock.unlock();
         the_condition_variable.notify_one();
@@ -61,13 +48,13 @@ public:
 
     bool empty() const
     {
-        boost::mutex::scoped_lock lock(the_mutex);
+        std::unique_lock<std::mutex> lock(the_mutex);
         return the_queue.empty();
     }
 
     bool try_pop(Data& popped_value)
     {
-        boost::mutex::scoped_lock lock(the_mutex);
+        std::unique_lock<std::mutex> lock(the_mutex);
         if (the_queue.empty())
             {
                 return false;
@@ -79,7 +66,7 @@ public:
 
     void wait_and_pop(Data& popped_value)
     {
-        boost::mutex::scoped_lock lock(the_mutex);
+        std::unique_lock<std::mutex> lock(the_mutex);
         while (the_queue.empty())
             {
                 the_condition_variable.wait(lock);
@@ -87,5 +74,27 @@ public:
         popped_value = the_queue.front();
         the_queue.pop();
     }
+
+    bool timed_wait_and_pop(Data& popped_value, int wait_ms)
+    {
+        std::unique_lock<std::mutex> lock(the_mutex);
+        if (the_queue.empty())
+            {
+                the_condition_variable.wait_for(lock, std::chrono::milliseconds(wait_ms));
+                if (the_queue.empty())
+                    {
+                        return false;
+                    }
+            }
+        popped_value = the_queue.front();
+        the_queue.pop();
+        return true;
+    }
+
+private:
+    std::queue<Data> the_queue;
+    mutable std::mutex the_mutex;
+    std::condition_variable the_condition_variable;
 };
-#endif
+
+#endif  // GNSS_SDR_CONCURRENT_QUEUE_H
