@@ -11,31 +11,20 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -------------------------------------------------------------------------
  */
 
-#ifndef GNSS_SDR_GALILEO_FNAV_MESSAGE_H_
-#define GNSS_SDR_GALILEO_FNAV_MESSAGE_H_
+#ifndef GNSS_SDR_GALILEO_FNAV_MESSAGE_H
+#define GNSS_SDR_GALILEO_FNAV_MESSAGE_H
 
 
 #include "Galileo_E5a.h"
@@ -52,7 +41,7 @@
 /*!
  * \brief This class handles the Galileo F/NAV Data message, as described in the
  * Galileo Open Service Signal in Space Interface Control Document (OS SIS ICD), Issue 1.2 (Nov 2015).
- * See https://www.gsc-europa.eu/system/files/galileo_documents/Galileo_OS_SIS_ICD.pdf
+ * See https://www.gsc-europa.eu/sites/default/files/sites/all/files/Galileo-OS-SIS-ICD.pdf
  */
 class Galileo_Fnav_Message
 {
@@ -205,8 +194,8 @@ private:
     int64_t read_navigation_signed(std::bitset<GALILEO_FNAV_DATA_FRAME_BITS> bits, const std::vector<std::pair<int32_t, int32_t>>& parameter);
 
     std::string omega0_1;
-    //std::string omega0_2;
-    //bool omega_flag;
+    // std::string omega0_2;
+    // bool omega_flag;
 };
 
-#endif /* GNSS_SDR_GALILEO_FNAV_MESSAGE_H_ */
+#endif  // GNSS_SDR_GALILEO_FNAV_MESSAGE_H
