@@ -5,25 +5,14 @@
  *
  * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
  *
  * GNSS-SDR is a software defined Global Navigation
  *          Satellite Systems receiver
  *
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -------------------------------------------------------------------------
  */
@@ -36,20 +25,18 @@
 #include <string>
 #include <vector>
 
-class observables_dump_reader
+class Observables_Dump_Reader
 {
 public:
-    observables_dump_reader(int n_channels);
-    ~observables_dump_reader();
+    explicit Observables_Dump_Reader(int n_channels);
+    ~Observables_Dump_Reader();
     bool read_binary_obs();
     bool restart();
     int64_t num_epochs();
     bool open_obs_file(std::string out_file);
     void close_obs_file();
 
-
-    //dump variables
-
+    // dump variables
     double* RX_time;
     double* TOW_at_current_symbol_s;
     double* Carrier_Doppler_hz;
@@ -64,4 +51,4 @@ private:
     std::ifstream d_dump_file;
 };
 
-#endif  //GNSS_SDR_OBSERVABLES_DUMP_READER_H
+#endif  // GNSS_SDR_OBSERVABLES_DUMP_READER_H
